( cd usr/lib/inkscape/plugins ; rm -rf libgimpgrad.so.0 )
( cd usr/lib/inkscape/plugins ; ln -sf libgimpgrad.so.0.0.0 libgimpgrad.so.0 )
( cd usr/lib/inkscape/plugins ; rm -rf libgimpgrad.so )
( cd usr/lib/inkscape/plugins ; ln -sf libgimpgrad.so.0.0.0 libgimpgrad.so )
( cd usr/lib/inkscape/plugins ; rm -rf libgrid.so.0 )
( cd usr/lib/inkscape/plugins ; ln -sf libgrid.so.0.0.0 libgrid.so.0 )
( cd usr/lib/inkscape/plugins ; rm -rf libgrid.so )
( cd usr/lib/inkscape/plugins ; ln -sf libgrid.so.0.0.0 libgrid.so )
